@@ -1,14 +1,14 @@
 package HTML::Widgets::NavMenu::EscapeHtml;
-$HTML::Widgets::NavMenu::EscapeHtml::VERSION = '1.0704';
+$HTML::Widgets::NavMenu::EscapeHtml::VERSION = '1.0800';
 use strict;
 use warnings;
 
-use base qw(Exporter);
+use parent qw(Exporter);
 
-use vars qw(@EXPORT);
+use vars qw(@EXPORT_OK);
 
 
-@EXPORT = (qw(escape_html));
+@EXPORT_OK = (qw(escape_html));
 
 sub escape_html
 {
@@ -27,17 +27,19 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 HTML::Widgets::NavMenu::EscapeHtml - provides a function to escape HTML.
 
 =head1 VERSION
 
-version 1.0704
+version 1.0800
 
 =head1 SYNOPSIS
 
-    use HTML::Widgets::NavMenu::EscapeHtml;
+    use HTML::Widgets::NavMenu::EscapeHtml qw/ escape_html /;
 
     my $escaped_html = escape_html($html);
 
@@ -45,47 +47,16 @@ version 1.0704
 
 Escapes the HTML.
 
-=head1 VERSION
-
-version 1.0704
-
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2006 Shlomi Fish, all rights reserved.
 
 This program is released under the following license: MIT X11.
 
-=head1 AUTHOR
-
-Shlomi Fish <shlomif@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is Copyright (c) 2014 by Shlomi Fish.
-
-This is free software, licensed under:
-
-  The MIT (X11) License
-
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/shlomif/perl-HTML-Widgets-NavMenu/issues>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
-=head2 Perldoc
-
-You can find documentation for this module with the perldoc command.
-
-  perldoc HTML::Widgets::NavMenu::EscapeHtml
-
 =head2 Websites
 
 The following websites have more information about this module, and may be of help to you. As always,
@@ -103,14 +74,6 @@ L<https://metacpan.org/release/HTML-Widgets-NavMenu>
 
 =item *
 
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/HTML-Widgets-NavMenu>
-
-=item *
-
 RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
@@ -119,22 +82,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=HTML-Widgets-NavMenu>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/HTML-Widgets-NavMenu>
-
-=item *
-
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/HTML-Widgets-NavMenu>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -183,4 +130,25 @@ L<https://github.com/shlomif/perl-HTML-Widgets-NavMenu>
 
   git clone git://github.com/shlomif/perl-HTML-Widgets-NavMenu.git
 
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/shlomif/perl-HTML-Widgets-NavMenu/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2014 by Shlomi Fish.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
 =cut
