@@ -1,24 +1,14 @@
-package HTML::Widgets::NavMenu::Iterator::Html::Item;
-$HTML::Widgets::NavMenu::Iterator::Html::Item::VERSION = '1.0704';
+package HTML::Widgets::NavMenu::Iterator::Html;
+$HTML::Widgets::NavMenu::Iterator::Html::VERSION = '1.0800';
 use strict;
 use warnings;
 
-use base qw(HTML::Widgets::NavMenu::Tree::Iterator::Item);
+use HTML::Widgets::NavMenu::Iterator::Html::Item ();
 
-sub get_url_type
-{
-    my $item = shift;
-    return (   $item->_node()->url_type()
-            || $item->_accum_state()->{'rec_url_type'}
-            || "rel" );
-}
 
-package HTML::Widgets::NavMenu::Iterator::Html;
-$HTML::Widgets::NavMenu::Iterator::Html::VERSION = '1.0704';
+use parent qw(HTML::Widgets::NavMenu::Iterator::Base);
 
-use base qw(HTML::Widgets::NavMenu::Iterator::Base);
-
-use HTML::Widgets::NavMenu::EscapeHtml;
+use HTML::Widgets::NavMenu::EscapeHtml qw/ escape_html /;
 
 sub _construct_new_item
 {
@@ -29,11 +19,16 @@ sub _construct_new_item
 }
 
 
+sub _is_top_separator
+{
+    return $_[0]->top->{_node}->{separator};
+}
+
 sub node_start
 {
     my $self = shift;
 
-    if ( $self->_is_root() )
+    if ( $self->{_is_root} )
     {
         return $self->_start_root();
     }
@@ -53,7 +48,7 @@ sub node_end
 {
     my $self = shift;
 
-    if ( $self->_is_root() )
+    if ( $self->{_is_root} )
     {
         return $self->end_root();
     }
@@ -121,22 +116,20 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 HTML::Widgets::NavMenu::Iterator::Html - an iterator for HTML.
 
 =head1 VERSION
 
-version 1.0704
+version 1.0800
 
 =head1 SYNOPSIS
 
 For internal use only.
 
-=head1 VERSION
-
-version 1.0704
-
 =head1 METHODS
 
 =head2 $self->node_start()
@@ -165,37 +158,10 @@ Copyright 2006 Shlomi Fish, all rights reserved.
 
 This program is released under the following license: MIT X11.
 
-=head1 AUTHOR
-
-Shlomi Fish <shlomif@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is Copyright (c) 2014 by Shlomi Fish.
-
-This is free software, licensed under:
-
-  The MIT (X11) License
-
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/shlomif/perl-HTML-Widgets-NavMenu/issues>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
-=head2 Perldoc
-
-You can find documentation for this module with the perldoc command.
-
-  perldoc HTML::Widgets::NavMenu::Iterator::Html::Item
-
 =head2 Websites
 
 The following websites have more information about this module, and may be of help to you. As always,
@@ -213,14 +179,6 @@ L<https://metacpan.org/release/HTML-Widgets-NavMenu>
 
 =item *
 
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/HTML-Widgets-NavMenu>
-
-=item *
-
 RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
@@ -229,22 +187,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=HTML-Widgets-NavMenu>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/HTML-Widgets-NavMenu>
-
-=item *
-
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/HTML-Widgets-NavMenu>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -293,4 +235,25 @@ L<https://github.com/shlomif/perl-HTML-Widgets-NavMenu>
 
   git clone git://github.com/shlomif/perl-HTML-Widgets-NavMenu.git
 
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/shlomif/perl-HTML-Widgets-NavMenu/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2014 by Shlomi Fish.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
 =cut
