@@ -1,18 +1,19 @@
 package HTML::Widgets::NavMenu::Tree::Iterator;
-$HTML::Widgets::NavMenu::Tree::Iterator::VERSION = '1.0704';
+$HTML::Widgets::NavMenu::Tree::Iterator::VERSION = '1.0800';
 use strict;
 use warnings;
 
-use base qw(HTML::Widgets::NavMenu::Object);
+use parent qw(HTML::Widgets::NavMenu::Object);
 
-use HTML::Widgets::NavMenu::Tree::Iterator::Stack;
-use HTML::Widgets::NavMenu::Tree::Iterator::Item;
+use HTML::Widgets::NavMenu::Tree::Iterator::Stack ();
+use HTML::Widgets::NavMenu::Tree::Iterator::Item  ();
 
 __PACKAGE__->mk_acc_ref(
     [
         qw(
             coords
             stack
+            _top
             )
     ]
 );
@@ -23,6 +24,7 @@ sub _init
     my $self = shift;
 
     $self->stack( HTML::Widgets::NavMenu::Tree::Iterator::Stack->new() );
+    $self->{_top} = undef();
 
     return 0;
 }
@@ -30,8 +32,7 @@ sub _init
 
 sub top
 {
-    my $self = shift;
-    return $self->stack()->top();
+    return shift(@_)->{_top};
 }
 
 sub _construct_new_item
@@ -70,27 +71,28 @@ sub _push_into_stack
     my $node = shift;
 
     $self->stack()->push(
-        $self->get_new_item(
+        $self->{_top} = $self->get_new_item(
             {
                 'node'        => $node,
-                'parent_item' => $self->top(),
+                'parent_item' => $self->{_top},
             }
-        ),
+        )
     );
+    return;
 }
 
 
 sub traverse
 {
-    my $self = shift;
+    my $self   = shift;
+    my $_items = $self->stack->_items;
 
     $self->_push_into_stack( $self->get_initial_node() );
+    $self->{_is_root} = ( scalar(@$_items) == 1 );
 
-    $self->coords( [] );
+    my $co = $self->coords( [] );
 
-    my $top_item;
-
-MAIN_LOOP: while ( $top_item = $self->top() )
+MAIN_LOOP: while ( my $top_item = $self->{_top} )
     {
         my $visited = $top_item->_is_visited();
 
@@ -107,7 +109,7 @@ MAIN_LOOP: while ( $top_item = $self->top() )
 
         if ( defined($sub_item) )
         {
-            push @{ $self->coords() }, $top_item->_visited_index();
+            push @$co, $top_item->_visited_index();
             $self->_push_into_stack(
                 $self->get_node_from_sub(
                     {
@@ -116,13 +118,16 @@ MAIN_LOOP: while ( $top_item = $self->top() )
                     }
                 ),
             );
+            $self->{_is_root} = ( scalar(@$_items) == 1 );
             next MAIN_LOOP;
         }
         else
         {
             $self->node_end();
-            $self->stack->pop();
-            pop( @{ $self->coords() } );
+            pop @$_items;
+            $self->{_top}     = $_items->[-1];
+            $self->{_is_root} = ( scalar(@$_items) == 1 );
+            pop @$co;
         }
     }
 
@@ -174,7 +179,7 @@ sub find_node_by_coords
                 'parent_item' => $item,
             }
         );
-        $idx++;
+        ++$idx;
         $internal_callback->();
     }
     return +{ 'item' => $item, };
@@ -188,6 +193,13 @@ sub get_coords
     return $self->coords();
 }
 
+sub _is_root
+{
+    my $self = shift;
+
+    return $self->{_is_root};
+}
+
 
 1;
 
@@ -195,22 +207,20 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 HTML::Widgets::NavMenu::Tree::Iterator - an iterator for HTML.
 
 =head1 VERSION
 
-version 1.0704
+version 1.0800
 
 =head1 SYNOPSIS
 
 For internal use only.
 
-=head1 VERSION
-
-version 1.0704
-
 =head1 METHODS
 
 =head2 coords
@@ -252,37 +262,10 @@ Copyright 2006 Shlomi Fish, all rights reserved.
 
 This program is released under the following license: MIT X11.
 
-=head1 AUTHOR
-
-Shlomi Fish <shlomif@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is Copyright (c) 2014 by Shlomi Fish.
-
-This is free software, licensed under:
-
-  The MIT (X11) License
-
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/shlomif/perl-HTML-Widgets-NavMenu/issues>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
-=head2 Perldoc
-
-You can find documentation for this module with the perldoc command.
-
-  perldoc HTML::Widgets::NavMenu::Tree::Iterator
-
 =head2 Websites
 
 The following websites have more information about this module, and may be of help to you. As always,
@@ -300,14 +283,6 @@ L<https://metacpan.org/release/HTML-Widgets-NavMenu>
 
 =item *
 
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/HTML-Widgets-NavMenu>
-
-=item *
-
 RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
@@ -316,22 +291,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=HTML-Widgets-NavMenu>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/HTML-Widgets-NavMenu>
-
-=item *
-
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/HTML-Widgets-NavMenu>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -380,4 +339,25 @@ L<https://github.com/shlomif/perl-HTML-Widgets-NavMenu>
 
   git clone git://github.com/shlomif/perl-HTML-Widgets-NavMenu.git
 
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/shlomif/perl-HTML-Widgets-NavMenu/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2014 by Shlomi Fish.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
 =cut
